@@ -1,7 +1,7 @@
 __title__ = 'vishap.defaults'
-__version__ = '0.1'
-__build__ = 0x000001
 __author__ = 'Artur Barseghyan'
+__copyright__ = 'Copyright (c) 2013 Artur Barseghyan'
+__license__ = 'GPL 2.0/LGPL 2.1'
 __all__ = ('PLUGINS_DIR', 'CONTRIB_DIR', 'PLUGIN_MODULE_NAME', 'DEBUG')
 
 PLUGINS_DIR = ('contrib', 'plugins')
